@@ -9,11 +9,12 @@
 \\wordwrap
 \\withMusicProperty
 \\with-url
+\\with-outline
 \\with-link
+\\with-dimensions-from
 \\with-dimensions
 \\with-color
 \\with
-\\whiteout-box
 \\whiteout
 \\whiteTriangleMarkup
 \\walkerHeadsMinor
@@ -47,6 +48,7 @@
 \\unit
 \\unfoldRepeats
 \\undo
+\\undertie
 \\underline
 \\unaCorda
 \\unHideNotes
@@ -90,6 +92,7 @@
 \\tieDotted
 \\tieDashed
 \\tieDashPattern
+\\tie
 \\thumb
 \\textSpannerUp
 \\textSpannerNeutral
@@ -105,6 +108,7 @@
 \\tagGroup
 \\tag
 \\table-of-contents
+\\table
 \\tablatureFormat
 \\tabStaffLineLayoutFunction
 \\tabFullNotation
@@ -248,6 +252,7 @@
 \\remove
 \\relative
 \\rehearsalMark
+\\reduceChords
 \\raise
 \\quotedEventTypes
 \\quotedCueEventTypes
@@ -308,19 +313,13 @@
 \\partialJazzExceptions
 \\partial
 \\partcombineUp
-\\partcombineUnisonoOnce
 \\partcombineUnisono
-\\partcombineSoloIOnce
-\\partcombineSoloIIOnce
 \\partcombineSoloII
 \\partcombineSoloI
 \\partcombineForce
 \\partcombineDown
-\\partcombineChordsOnce
 \\partcombineChords
-\\partcombineAutomaticOnce
 \\partcombineAutomatic
-\\partcombineApartOnce
 \\partcombineApart
 \\partcombine
 \\partCombineTextsOnNote
@@ -340,10 +339,12 @@
 \\pad-markup
 \\pad-around
 \\p
+\\overtie
 \\overrideTimeSignatureSettings
 \\overrideProperty
 \\override-lines
 \\override
+\\overlay
 \\oval
 \\ottava
 \\oriscus
@@ -582,6 +583,7 @@
 \\drummode
 \\drumStyleTable
 \\drumPitchTable
+\\draw-squiggle-line
 \\draw-line
 \\draw-hline
 \\draw-dotted-line
@@ -792,6 +794,7 @@
 \\B
 \\AncientRemoveEmptyStaffContext
 \\A
+staff
 spacing
 signature
 routine
@@ -877,7 +880,7 @@ NoteNames
 NoteHead
 New_fingering_engraver
 Multi_measure_rest_engraver
-Midi_control_function_performer
+Midi_control_change_performer
 Metronome_mark_engraver
 Mensural_ligature_engraver
 MensuralVoice
